import setuptools

setuptools.setup(
    name="MarketVision",
    version="0.0.3",
    author="Kai-Wei Tian",
    author_email="m.123051427@gmail.com",
    url = "https://github.com/m21248074/MarketVision",
    install_requires=['yfinance'],
    packages=["MarketVision"]
)